@@ -14,7 +14,7 @@ import (
 // FontsDir denotes the path to the user's fonts directory on Unix-like systems.
 var FontsDir = path.Join(os.Getenv("HOME"), "/.local/share/fonts")
 
-func install(font *Font, _ bool) (err error) {
+func install(font *Font, _ bool) error {
 	// On Linux, fontconfig can understand subdirectories. So, to keep the
 	// font directory clean, install all font files for a particular font
 	// family into a subdirectory named after the family (with hyphens instead
@@ -23,7 +23,7 @@ func install(font *Font, _ bool) (err error) {
 		strings.ToLower(strings.ReplaceAll(font.Family, " ", "-")),
 		path.Base(font.FileName))
 
-	if err = os.MkdirAll(path.Dir(fullPath), 0700); err != nil {
+	if err := os.MkdirAll(path.Dir(fullPath), 0700); err != nil {
 		return err
 	}
 
