@@ -146,8 +146,9 @@ func (g *Git) Template() string {
 }
 
 func (g *Git) Enabled() bool {
-	g.Working = &GitStatus{}
-	g.Staging = &GitStatus{}
+	statusFormats := g.props.GetKeyValueMap(StatusFormats, map[string]string{})
+	g.Working = &GitStatus{ScmStatus: ScmStatus{Formats: statusFormats}}
+	g.Staging = &GitStatus{ScmStatus: ScmStatus{Formats: statusFormats}}
 	g.User = &User{}
 
 	if !g.shouldDisplay() {
